==> estateplat-common-1.2.4-20181031.015027-44-sources.jar: cn/gtmap/estateplat/model/exchange/national/InfApplyWlxx.java <==
package cn.gtmap.estateplat.model.exchange.national;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2017/9/28
 * @description EMS物流信息
 */
@Table(name = "inf_apply_wlxx")
public class InfApplyWlxx {
    @Id
    private String no;//唯一标识
    private String internal_no;//办件编号
    private String zwfwzx_code;//政务服务中心编码
    private String ems_ord_no;//信封流水号
    private String mail_num;//快递单号
    private String gov_tb_name;//受理台席名称（窗口号）
    private String post_type;//邮寄类型
    private String net_type;//寄件内容类型
    private String buss_type;//收费类型
    private String send_name;//发件人姓名
    private String send_prov;//发件人省
    private String send_city;//发件人市
    private String send_country;//发件人区县
    private String send_strect;//发件地址
    private String send_phone;//发件人手机
    private String send_call;//发件人联系电话
    private String rcv_name;//收件人名称
    private String rcv_prov;//收件人省
    private String rcv_city;//收件人市
    private String rcv_country;//收件人区县
    private String rcv_strect;//收件地址
    private String rcv_phone;//收件人手机
    private String rcv_call;//收件人联系电话
    private String rcv_postcode;//收件人邮编
    private String item;//邮寄材料说明
    private String chk_code;//取件验证码
    private String deptno;//办理部门编码
    private String orgname;//办理部门
    private String issend;//是否已经寄送
    private Date sendtime;//寄送时间
    private Date sync_date;//信息同步读取时间
    private String sync_sign;//信息同步标志
    private String sync_error_desc;//信息同步错误原因
    private String data_sources;//数据来源

    public String getNo() {
        return no;
    }

    public void setNo(String no) {
        this.no = no;
    }

    public String getInternal_no() {
        return internal_no;
    }

    public void setInternal_no(String internal_no) {
        this.internal_no = internal_no;
    }

    public String getZwfwzx_code() {
        return zwfwzx_code;
    }

    public void setZwfwzx_code(String zwfwzx_code) {
        this.zwfwzx_code = zwfwzx_code;
    }

    public String getEms_ord_no() {
        return ems_ord_no;
    }

    public void setEms_ord_no(String ems_ord_no) {
        this.ems_ord_no = ems_ord_no;
    }

    public String getMail_num() {
        return mail_num;
    }

    public void setMail_num(String mail_num) {
        this.mail_num = mail_num;
    }

    public String getGov_tb_name() {
        return gov_tb_name;
    }

    public void setGov_tb_name(String gov_tb_name) {
        this.gov_tb_name = gov_tb_name;
    }

    public String getPost_type() {
        return post_type;
    }

    public void setPost_type(String post_type) {
        this.post_type = post_type;
    }

    public String getNet_type() {
        return net_type;
    }

    public void setNet_type(String net_type) {
        this.net_type = net_type;
    }

    public String getBuss_type() {
        return buss_type;
    }

    public void setBuss_type(String buss_type) {
        this.buss_type = buss_type;
    }

    public String getSend_name() {
        return send_name;
    }

    public void setSend_name(String send_name) {
        this.send_name = send_name;
    }

    public String getSend_prov() {
        return send_prov;
    }

    public void setSend_prov(String send_prov) {
        this.send_prov = send_prov;
    }

    public String getSend_city() {
        return send_city;
    }

    public void setSend_city(String send_city) {
        this.send_city = send_city;
    }

    public String getSend_country() {
        return send_country;
    }

    public void setSend_country(String send_country) {
        this.send_country = send_country;
    }

    public String getSend_strect() {
        return send_strect;
    }

    public void setSend_strect(String send_strect) {
        this.send_strect = send_strect;
    }

    public String getSend_phone() {
        return send_phone;
    }

    public void setSend_phone(String send_phone) {
        this.send_phone = send_phone;
    }

    public String getSend_call() {
        return send_call;
    }

    public void setSend_call(String send_call) {
        this.send_call = send_call;
    }

    public String getRcv_name() {
        return rcv_name;
    }

    public void setRcv_name(String rcv_name) {
        this.rcv_name = rcv_name;
    }

    public String getRcv_prov() {
        return rcv_prov;
    }

    public void setRcv_prov(String rcv_prov) {
        this.rcv_prov = rcv_prov;
    }

    public String getRcv_city() {
        return rcv_city;
    }

    public void setRcv_city(String rcv_city) {
        this.rcv_city = rcv_city;
    }

    public String getRcv_country() {
        return rcv_country;
    }

    public void setRcv_country(String rcv_country) {
        this.rcv_country = rcv_country;
    }

    public String getRcv_strect() {
        return rcv_strect;
    }

    public void setRcv_strect(String rcv_strect) {
        this.rcv_strect = rcv_strect;
    }

    public String getRcv_phone() {
        return rcv_phone;
    }

    public void setRcv_phone(String rcv_phone) {
        this.rcv_phone = rcv_phone;
    }

    public String getRcv_call() {
        return rcv_call;
    }

    public void setRcv_call(String rcv_call) {
        this.rcv_call = rcv_call;
    }

    public String getRcv_postcode() {
        return rcv_postcode;
    }

    public void setRcv_postcode(String rcv_postcode) {
        this.rcv_postcode = rcv_postcode;
    }

    public String getItem() {
        return item;
    }

    public void setItem(String item) {
        this.item = item;
    }

    public String getChk_code() {
        return chk_code;
    }

    public void setChk_code(String chk_code) {
        this.chk_code = chk_code;
    }

    public String getDeptno() {
        return deptno;
    }

    public void setDeptno(String deptno) {
        this.deptno = deptno;
    }

    public String getOrgname() {
        return orgname;
    }

    public void setOrgname(String orgname) {
        this.orgname = orgname;
    }

    public String getIssend() {
        return issend;
    }

    public void setIssend(String issend) {
        this.issend = issend;
    }

    public Date getSendtime() {
        return sendtime;
    }

    public void setSendtime(Date sendtime) {
        this.sendtime = sendtime;
    }

    public Date getSync_date() {
        return sync_date;
    }

    public void setSync_date(Date sync_date) {
        this.sync_date = sync_date;
    }

    public String getSync_sign() {
        return sync_sign;
    }

    public void setSync_sign(String sync_sign) {
        this.sync_sign = sync_sign;
    }

    public String getSync_error_desc() {
        return sync_error_desc;
    }

    public void setSync_error_desc(String sync_error_desc) {
        this.sync_error_desc = sync_error_desc;
    }

    public String getData_sources() {
        return data_sources;
    }

    public void setData_sources(String data_sources) {
        this.data_sources = data_sources;
    }
}

==> estateplat-common-1.2.4-20190226.065427-110-sources.jar: cn/gtmap/estateplat/model/exchange/national/InfApplyWlxx.java <==
package cn.gtmap.estateplat.model.exchange.national;

import javax.persistence.Id;
import javax.persistence.Table;
import java.util.Date;

/*
 * @author <a href="mailto:yinyao@gtmap.cn">yinyao</a>
 * @version 1.0, 2017/9/28
 * @description EMS物流信息
 */
@Table(name = "inf_apply_wlxx")
public class InfApplyWlxx {
    @Id
    private String no;//唯一标识
    private String internal_no;//办件编号
    private String zwfwzx_code;//政务服务中心编码
    private String ems_ord_no;//信封流水号
    private String mail_num;//快递单号
    private String gov_tb_name;//受理台席名称（窗口号）
    private String post_type;//邮寄类型
    private String net_type;//寄件内容类型
    private String buss_type;//收费类型
    private String send_name;//发件人姓名
    private String send_prov;//发件人省
    private String send_city;//发件人市
    private String send_country;//发件人区县
    private String send_strect;//发件地址
    private String send_phone;//发件人手机
    private String send_call;//发件人联系电话
    private String rcv_name;//收件人名称
    private String rcv_prov;//收件人省
    private String rcv_city;//收件人市
    private String rcv_country;//收件人区县
    private String rcv_strect;//收件地址
    private String rcv_phone;//收件人手机
    private String rcv_call;//收件人联系电话
    private String rcv_postcode;//收件人邮编
    private String item;//邮寄材料说明
    private String chk_code;//取件验证码
    private String deptno;//办理部门编码
    private String orgname;//办理部门
    private String issend;//是否已经寄送
    private Date sendtime;//寄送时间
    private Date sync_date;//信息同步读取时间
    private String sync_sign;//信息同步标志
    private String sync_error_desc;//信息同步错误原因
    private String data_sources;//数据来源
    private String proid;//业务号

    public String getNo() {
        return no;
    }

    public void setNo(String no) {
        this.no = no;
    }

    public String getInternal_no() {
        return internal_no;
    }

    public void setInternal_no(String internal_no) {
        this.internal_no = internal_no;
    }

    public String getZwfwzx_code() {
        return zwfwzx_code;
    }

    public void setZwfwzx_code(String zwfwzx_code) {
        this.zwfwzx_code = zwfwzx_code;
    }

    public String getEms_ord_no() {
        return ems_ord_no;
    }

    public void setEms_ord_no(String ems_ord_no) {
        this.ems_ord_no = ems_ord_no;
    }

    public String getMail_num() {
        return mail_num;
    }

    public void setMail_num(String mail_num) {
        this.mail_num = mail_num;
    }

    public String getGov_tb_name() {
        return gov_tb_name;
    }

    public void setGov_tb_name(String gov_tb_name) {
        this.gov_tb_name = gov_tb_name;
    }

    public String getPost_type() {
        return post_type;
    }

    public void setPost_type(String post_type) {
        this.post_type = post_type;
    }

    public String getNet_type() {
        return net_type;
    }

    public void setNet_type(String net_type) {
        this.net_type = net_type;
    }

    public String getBuss_type() {
        return buss_type;
    }

    public void setBuss_type(String buss_type) {
        this.buss_type = buss_type;
    }

    public String getSend_name() {
        return send_name;
    }

    public void setSend_name(String send_name) {
        this.send_name = send_name;
    }

    public String getSend_prov() {
        return send_prov;
    }

    public void setSend_prov(String send_prov) {
        this.send_prov = send_prov;
    }

    public String getSend_city() {
        return send_city;
    }

    public void setSend_city(String send_city) {
        this.send_city = send_city;
    }

    public String getSend_country() {
        return send_country;
    }

    public void setSend_country(String send_country) {
        this.send_country = send_country;
    }

    public String getSend_strect() {
        return send_strect;
    }

    public void setSend_strect(String send_strect) {
        this.send_strect = send_strect;
    }

    public String getSend_phone() {
        return send_phone;
    }

    public void setSend_phone(String send_phone) {
        this.send_phone = send_phone;
    }

    public String getSend_call() {
        return send_call;
    }

    public void setSend_call(String send_call) {
        this.send_call = send_call;
    }

    public String getRcv_name() {
        return rcv_name;
    }

    public void setRcv_name(String rcv_name) {
        this.rcv_name = rcv_name;
    }

    public String getRcv_prov() {
        return rcv_prov;
    }

    public void setRcv_prov(String rcv_prov) {
        this.rcv_prov = rcv_prov;
    }

    public String getRcv_city() {
        return rcv_city;
    }

    public void setRcv_city(String rcv_city) {
        this.rcv_city = rcv_city;
    }

    public String getRcv_country() {
        return rcv_country;
    }

    public void setRcv_country(String rcv_country) {
        this.rcv_country = rcv_country;
    }

    public String getRcv_strect() {
        return rcv_strect;
    }

    public void setRcv_strect(String rcv_strect) {
        this.rcv_strect = rcv_strect;
    }

    public String getRcv_phone() {
        return rcv_phone;
    }

    public void setRcv_phone(String rcv_phone) {
        this.rcv_phone = rcv_phone;
    }

    public String getRcv_call() {
        return rcv_call;
    }

    public void setRcv_call(String rcv_call) {
        this.rcv_call = rcv_call;
    }

    public String getRcv_postcode() {
        return rcv_postcode;
    }

    public void setRcv_postcode(String rcv_postcode) {
        this.rcv_postcode = rcv_postcode;
    }

    public String getItem() {
        return item;
    }

    public void setItem(String item) {
        this.item = item;
    }

    public String getChk_code() {
        return chk_code;
    }

    public void setChk_code(String chk_code) {
        this.chk_code = chk_code;
    }

    public String getDeptno() {
        return deptno;
    }

    public void setDeptno(String deptno) {
        this.deptno = deptno;
    }

    public String getOrgname() {
        return orgname;
    }

    public void setOrgname(String orgname) {
        this.orgname = orgname;
    }

    public String getIssend() {
        return issend;
    }

    public void setIssend(String issend) {
        this.issend = issend;
    }

    public Date getSendtime() {
        return sendtime;
    }

    public void setSendtime(Date sendtime) {
        this.sendtime = sendtime;
    }

    public Date getSync_date() {
        return sync_date;
    }

    public void setSync_date(Date sync_date) {
        this.sync_date = sync_date;
    }

    public String getSync_sign() {
        return sync_sign;
    }

    public void setSync_sign(String sync_sign) {
        this.sync_sign = sync_sign;
    }

    public String getSync_error_desc() {
        return sync_error_desc;
    }

    public void setSync_error_desc(String sync_error_desc) {
        this.sync_error_desc = sync_error_desc;
    }

    public String getData_sources() {
        return data_sources;
    }

    public void setData_sources(String data_sources) {
        this.data_sources = data_sources;
    }

    public String getProid() {
        return proid;
    }

    public void setProid(String proid) {
        this.proid = proid;
    }
}
